@@ -20,7 +20,7 @@ rtfNCA = function(fileName="Temp-NCA.rtf", concData, colSubj="Subject", colTime=
     x = concData[concData[,colSubj]==cID, colTime]
     y = concData[concData[,colSubj]==cID, colConc]
     tabRes = sNCA(x, y, dose=dose, adm=adm, dur=dur, doseUnit=doseUnit, timeUnit=timeUnit, concUnit=concUnit, down=down, MW=MW)
-    tRes = txtNCA(x, y, dose=dose, adm=adm, dur=dur, doseUnit=doseUnit, timeUnit=timeUnit, concUnit=concUnit, down=down, MW=MW, returnNA=FALSE) 
+    tRes = txtNCA(x, y, dose=dose, adm=adm, dur=dur, doseUnit=doseUnit, timeUnit=timeUnit, concUnit=concUnit, down=down, MW=MW) 
     Res = c(Res, tRes)
 
     addPageBreak(rtf)
